# python-vercel-kv
vercel-kv python version
wapper for https://vercel.com/docs/storage/vercel-kv/rest-api

### install
```
pip install vercel_kv
```

### usage

set env
```
export VERCEL_KV_URL="redis://default:4ce4fedaa7924fXXXXXXXXXXXXX.vercel-storage.com:34840"
export VERCEL_KV_REST_API_URL="https://champion-XXXXXl-storage.com"
export VERCEL_KV_REST_API_TOKEN="AYgYASQgY2FiXXXXXXXXXXXXXXXZiZWE4NmIyNmI4Y2MzZjE3ZjY="
export VERCEL_KV_REST_API_READ_ONLY_TOKEN="AogYASQgXXXXXXXXXXXXXXXXXX39rhNEJyIFjEPv0rY6s="
```

run test.py